@@ -2,34 +2,24 @@ package Net::Twitter::Diff;
 
 use warnings;
 use strict;
-use base qw/Net::Twitter/;
+use Moose;
+extends 'Net::Twitter::Core';
+with 'Net::Twitter::Role::API::REST';
+
 use Array::Diff;
 
-our $VERSION = '0.04';
+our $VERSION = '0.10';
 
 sub xfollowing {
     my $self = shift;
     my $id   = shift;
 
-      my $url = $self->{apiurl} . "/statuses/friends" ;
-      $url .= (defined $id) ? "/$id.json" : ".json";
-      $url .= '?page=';
-    
     my $page = 1;
     my @data = ();
     while(1){
-        my $page_url = $url . $page ;
-        my $req = $self->{ua}->get($page_url);
-
-        die 'fail to connect to twitter. maybe over Rate limit exceeded or auth error' unless $req->is_success;
-        return [] if $req->content eq 'null';
-
-        my $res = JSON::Any->jsonToObj($req->content) ;
-
-        last unless scalar @{ $res } ;
-        push @data , @{ $res } ;
-
-
+        my $res = $self->following( { id => $id , page => $page } );
+        last unless scalar @{ $res };
+        push @data , @{ $res };
         $page++;
     }
 
@@ -38,22 +28,13 @@ sub xfollowing {
 
 sub xfollowers {
     my $self = shift;
-    
+
     my $page = 1;
     my @data = ();
     while(1){
-        my $url = $self->{apiurl} . "/statuses/followers.json?page=$page" ;
-        my $req = $self->{ua}->get($url);
-
-        die 'fail to connect to twitter. maybe over Rate limit exceeded or auth error' unless $req->is_success;
-        return [] if $req->content eq 'null';
-
-        my $res = JSON::Any->jsonToObj($req->content) ;
-
-        last unless scalar @{ $res } ;
-        push @data , @{ $res } ;
-
-
+        my $res = $self->followers({ page => $page });
+        last unless scalar @{ $res };
+        push @data , @{ $res };
         $page++;
     }
 
@@ -66,7 +47,7 @@ sub diff {
 
     my $res = {};
     my $followings_hash = $self->xfollowing();
-    my $followers_hash   = $self->xfollowers();
+    my $followers_hash  = $self->xfollowers();
     my $followers = [];
     my $followings = [];
 
@@ -78,19 +59,19 @@ sub diff {
         push @{ $followers } , $item->{screen_name};
     }
 
-    my $diff = Array::Diff->diff( $followers , $followings );
+    my $diff = Array::Diff->diff( [ sort @{$followers} ] , [ sort @{$followings} ] );
 
-    $res->{not_following} = $diff->deleted; 
-    $res->{not_followed}  = $diff->added; 
+    $res->{not_following} = $diff->deleted;
+    $res->{not_followed}  = $diff->added;
     my @communicated = ();
     my $not_followed_ref = {};
     for my $user ( @{  $res->{not_followed} } ) {
-           $not_followed_ref->{ $user } = 1; 
+           $not_followed_ref->{ $user } = 1;
     }
 
     for my $screen_name ( @{ $followings } ) {
         if ( !defined $not_followed_ref->{ $screen_name  } ) {
-            push @communicated , $screen_name 
+            push @communicated , $screen_name;
         }
     }
 
@@ -108,7 +89,6 @@ sub comp_following {
     my $me_ref = $self->xfollowing();
     my $him_ref = $self->xfollowing( $id );
 
-    
     my $me  = [];
     my $him = [];
     my $me_hash = {};
@@ -121,15 +101,15 @@ sub comp_following {
         push @{ $him } , $item->{screen_name};
     }
 
-    my $diff = Array::Diff->diff( $me , $him );
+    my $diff = Array::Diff->diff( [sort @$me ], [ sort @$him ] );
 
-    $res->{only_me} = $diff->deleted; 
-    $res->{not_me}  = $diff->added; 
+    $res->{only_me} = $diff->deleted;
+    $res->{not_me}  = $diff->added;
     my @communicated = ();
 
     for my $screen_name ( @{ $him } ) {
         if ( defined $me_hash->{ $screen_name  } ) {
-            push @communicated , $screen_name 
+            push @communicated , $screen_name;
         }
     }
 
@@ -144,12 +124,12 @@ sub comp_following {
 
 Net::Twitter::Diff - Twitter Diff
 
-=head1 SYNOPSYS
+=head1 SYNOPSIS
 
     use Net::Twitter::Diff;
 
     my $diff = Net::Twitter::Diff->new(  username => '******' , password => '******');
-    
+
     my $res = $diff->diff();
 
     # get screen_names who you are not following but they are.
@@ -158,8 +138,8 @@ Net::Twitter::Diff - Twitter Diff
     # get screen_names who they are not following but you are.
     print Dumper $res->{not_followed};
 
-    # get screen_names who you are following them and also they follow you. 
-    print Dumper $res->{communicated}; 
+    # get screen_names who you are following them and also they follow you.
+    print Dumper $res->{communicated};
 
 
     my $res2 = $diff->comp_following( 'somebody_twitter_name' );
@@ -174,12 +154,9 @@ Net::Twitter::Diff - Twitter Diff
     print Dumper $res2->{share} ;
 
 
-    # If you want , this module use Net::Twitter as base so you can use methods Net::Twitter has.
-    $diff->update('My current Status');
-    
 =head1 DESCRIPTION
 
-Handy when you want to know relationshop between your followers and follwoings
+Handy when you want to know relationshops between your followers and followings
 and when you wnat to compare your following and somebody's.
 
 =head1 METHOD
@@ -202,7 +179,7 @@ get screen_names who they are not following but you are.
 
 =item B<communicated>
 
-get screen_names who you are following them and also they follow you. 
+get screen_names who you are following them and also they follow you.
 
 =back
 
@@ -242,6 +219,6 @@ L<Net::Twitter>
 
 =head1 AUTHOR
 
-Tomohiro Teranishi<tomohiro.teranishi@gmail.com>
+Tomohiro Teranishi <tomohiro.teranishi@gmail.com>
 
 =cut
